## Human disturbance causes widespread disruption of animal movement ##
# August 2020 #

# Load the appropriate packages
library(metafor)
library(brms)
library(dplyr)
library(sjPlot)

## Data
# Import the data and check the structure
moveDF<-read.csv("move_dist_data.csv", na.strings=c("","NA"))
str(moveDF)

# Create a hybrid variable of disturbance type and taxonomic group ('Dist_taxa')
moveDF$Dist_taxa<-as.factor(paste(moveDF$Disturbance_type,"_",moveDF$Taxonomic_group, sep = ""))

# Convert Record_number and TrophicLevel to factors
moveDF$Record_number<-as.factor(moveDF$Record_number)
moveDF$TrophicLevel<-as.factor(moveDF$TrophicLevel)

## Publication bias
# Make a funnel plot, run Egger's test and calculate the fail safe number for the movement distance data
moveDFdist<-subset(moveDF, Movement_type == "Distance" & Variance != "NA"); moveDFdist <-droplevels(moveDFdist)
funnel(x = moveDFdist$lnRR, sei = moveDFdist$SE, pch=1)
regtest(x = moveDFdist$lnRR, sei = moveDFdist$SE)
fsn(yi = moveDFdist$lnRR, vi = moveDFdist$Variance, type="Rosenberg")

# Make a funnel plot and run Egger's test for the home range data
moveDFhr<-subset(moveDF, Movement_type == "Home range" & Variance != "NA"); moveDFhr<-droplevels(moveDFhr)
funnel(x = moveDFhr$lnRR, sei = moveDFhr$SE, pch=1)
regtest(x = moveDFhr$lnRR, sei = moveDFhr$SE)

#######################################
### Bayesian modelling
## Model set 1: null models to estimate overall effects
#Unweighted, home range
gm1<-brm(lnRR ~ 1 + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Home range"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(gm1); plot(gm1)

#Unweighted, movement rate
gm2<-brm(lnRR ~ 1 + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(gm2); plot(gm2)

#Weighted, home range
gm3<-brm(lnRR|se(SE, sigma = TRUE) ~ 1 + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Home range"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(gm3); plot(gm3)

#Weighted, movement rate
gm4<-brm(lnRR|se(SE, sigma = TRUE) ~ 1 + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(gm4); plot(gm4)

# Create a model results table
tab_model(gm2, gm4, gm1, gm3, show.icc = FALSE, show.re.var = FALSE, show.r2 = FALSE, show.ngroups = FALSE, dv.labels=c("MD unweighted", "MD weighted","HR unweighted", "HR weighted"))

## Estimate mean positive or negative effects for both movement types combined
# Positive effects only, both movement types, unweighted
gm5<-brm(lnRR ~ 1 + (1|Record_number)+(1| Species), data= subset(moveDF, lnRR >= 0), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)), control = list(adapt_delta = 0.99))
summary(gm5); plot(gm5)

# Negative effects only, both movement types, unweighted
gm6<-brm(lnRR ~ 1 + (1|Record_number)+(1| Species), data= subset(moveDF, lnRR <= 0), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)), control = list(adapt_delta = 0.99))
summary(gm6); plot(gm6)

# Positive effects only, both movement types, weighted
gm7<-brm(lnRR|se(SE, sigma = TRUE) ~ 1 + (1|Record_number)+(1| Species), data= subset(moveDF, lnRR >= 0), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)), control = list(adapt_delta = 0.99))
summary(gm7); plot(gm7)

# Negative effects only, both movement types, weighted
gm8<-brm(lnRR|se(SE, sigma = TRUE) ~ 1 + (1|Record_number)+(1| Species), data= subset(moveDF, lnRR <= 0), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)), control = list(adapt_delta = 0.99))
summary(gm8); plot(gm8)

# Create a model results table
tab_model( gm5, gm7, gm6, gm8,show.icc = FALSE, show.re.var = FALSE, show.r2 = FALSE, show.ngroups = FALSE, dv.labels=c("Positive unweighted", "Positive weighted","Negative unweighted", "Negative weighted"))

#############################################################
## Model set 2: test whether responses vary according to taxonomic class
#Unweighted, home range
tc1<-brm(lnRR ~ Taxonomic_group-1 + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Home range" & Taxonomic_group != "Amphibians"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(tc1); plot(tc1)

#Unweighted, movement rate
tc2<-brm(lnRR ~ Taxonomic_group-1 + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(tc2); plot(tc2)

#Weighted, home range
tc3<-brm(lnRR|se(SE, sigma = TRUE) ~ Taxonomic_group-1 + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Home range"& Taxonomic_group != "Amphibians"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(tc3); plot(tc3)

#Weighted, movement rate
tc4<-brm(lnRR|se(SE, sigma = TRUE) ~ Taxonomic_group-1 + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(tc4); plot(tc4)

tab_model(tc2, tc4, tc1,tc3, show.icc = FALSE, show.re.var = FALSE, show.r2 = FALSE, show.ngroups = FALSE, dv.labels=c("MD unweighted", "MD weighted","HR unweighted", "HR weighted"), string.pred = "Taxonomic group")

###########################################################
## Model set 3: test whether responses vary according to trophic level 
#Unweighted, home range
tr1<-brm(lnRR ~ TrophicLevel-1 + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Home range"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(tr1); plot(tr1)

#Unweighted, movement rate
tr2<-brm(lnRR ~ TrophicLevel-1 + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(tr2); plot(tr2)

#Weighted, home range
tr3<-brm(lnRR|se(SE, sigma = TRUE) ~ TrophicLevel-1 + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Home range"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(tr3); plot(tr3)

#Weighted, movement rate
tr4<-brm(lnRR|se(SE, sigma = TRUE) ~ TrophicLevel-1 + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(tr4); plot(tr4)

# Create a model results table
tab_model(tr2, tr4, tr1,tr3, show.icc = FALSE, show.re.var = FALSE, show.r2 = FALSE, show.ngroups = FALSE, dv.labels=c("MD unweighted", "MD weighted","HR unweighted", "HR weighted"), string.pred = "Trophic level")

########################################################
## Model set 4: test whether responses vary according to body mass 

### Mammals ###
#Unweighted, home range, mammals
bm1_mam<-brm(lnRR ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Home range" & Taxonomic_group == "Mammals"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(bm1_mam); plot(bm1_mam)

#Unweighted, movement rate, mammals
bm2_mam<-brm(lnRR ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance" & Taxonomic_group == "Mammals"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(bm2_mam); plot(bm2_mam)

#Weighted, home range, mammals
bm3_mam<-brm(lnRR|se(SE, sigma = TRUE) ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Home range" & Taxonomic_group == "Mammals"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(bm3_mam); plot(bm3_mam)

#Weighted, movement rate, mammals
bm4_mam<-brm(lnRR|se(SE, sigma = TRUE) ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance" & Taxonomic_group == "Mammals"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(bm4_mam); plot(bm4_mam)

### Birds ###
#Unweighted, home range, birds
bm1_brd<-brm(lnRR ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Home range" & Taxonomic_group == "Birds"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(bm1_brd); plot(bm1_brd)

#Unweighted, movement rate, birds
bm2_brd<-brm(lnRR ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance" & Taxonomic_group == "Birds"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.999))
summary(bm2_brd); plot(bm2_brd)

#Weighted, home range, birds
bm3_brd<-brm(lnRR|se(SE, sigma = TRUE) ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Home range" & Taxonomic_group == "Birds"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(bm3_brd); plot(bm3_brd)

#Weighted, movement rate, birds
bm4_brd<-brm(lnRR|se(SE, sigma = TRUE) ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance" & Taxonomic_group == "Birds"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(bm4_brd); plot(bm4_brd)

### Reptiles ###
#Unweighted, home range, reptiles
bm1_rep<-brm(lnRR ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Home range" & Taxonomic_group == "Reptiles"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(bm1_rep); plot(bm1_rep)

#Unweighted, movement rate, reptiles
bm2_rep<-brm(lnRR ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance" & Taxonomic_group == "Reptiles"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(bm2_rep); plot(bm2_rep)

#Weighted, home range, reptiles
bm3_rep<-brm(lnRR|se(SE, sigma = TRUE) ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Home range" & Taxonomic_group == "Reptiles"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.999))
summary(bm3_rep); plot(bm3_rep)

#Weighted, movement rate, reptiles
bm4_rep<-brm(lnRR|se(SE, sigma = TRUE) ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance" & Taxonomic_group == "Reptiles"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.999))
summary(bm4_rep); plot(bm4_rep)

### Fish ###
#Unweighted, home range, fish
bm1_fsh<-brm(lnRR ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Home range" & Taxonomic_group == "Fish"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.999))
summary(bm1_fsh); plot(bm1_fsh)

#Unweighted, movement rate, fish
bm2_fsh<-brm(lnRR ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance" & Taxonomic_group == "Fish"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(bm2_fsh); plot(bm2_fsh)

#Weighted, home range, fish
bm3_fsh<-brm(lnRR|se(SE, sigma = TRUE) ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Home range" & Taxonomic_group == "Fish"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.999))
summary(bm3_fsh); plot(bm3_fsh)

#Weighted, movement rate, fish
bm4_fsh<-brm(lnRR|se(SE, sigma = TRUE) ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance" & Taxonomic_group == "Fish"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.999))
summary(bm4_fsh); plot(bm4_fsh)

### Amphibians ###
#Unweighted, movement rate, amphibians
bm2_amp<-brm(lnRR ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance" & Taxonomic_group == "Amphibians"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.999))
summary(bm2_amp); plot(bm2_amp)

#Weighted, movement rate, amphibians
bm4_amp<-brm(lnRR|se(SE, sigma = TRUE) ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance" & Taxonomic_group == "Amphibians"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99999))
summary(bm4_amp); plot(bm4_amp)

### Arthropods ###
#Unweighted, movement rate, arthropods
bm2_inv<-brm(lnRR ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance" & Taxonomic_group == "Arthropods"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(bm2_inv); plot(bm2_inv)

#Weighted, movement rate, arthropods
bm4_inv<-brm(lnRR|se(SE, sigma = TRUE) ~  log_BodyMass + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance" & Taxonomic_group == "Arthropods"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.999))
summary(bm4_inv); plot(bm4_inv)

# Create a model results table
tab_model(bm2_mam, bm4_mam, bm2_brd, bm4_brd, bm2_rep, bm4_rep, bm2_fsh, bm4_fsh, bm2_amp, bm4_amp, bm2_inv, bm4_inv, bm1_mam, bm3_mam, bm1_brd, bm3_brd, bm1_rep, bm3_rep, bm1_fsh, bm3_fsh, show.icc = FALSE, show.re.var = FALSE, show.r2 = FALSE, show.ngroups = FALSE, title = "Home range", dv.labels=c("Mammals MD unweighted", "Mammals MD weighted","Birds MD unweighted", "Birds MD weighted","Reptiles MD unweighted", "Reptiles MD weighted","Fish MD unweighted", "Fish MD weighted","Amphibians MD unweighted", "Amphibians MD weighted","Arthropods MD unweighted", "Arthropods MD weighted","Mammals HR unweighted", "Mammals HR weighted","Birds HR unweighted","Birds HR weighted","Reptiles HR unweighted","Reptiles HR weighted","Fish HR unweighted","Fish HR weighted"), string.pred = "Body mass")

###############################################################
## Model set 5: test whether responses vary according to disturbance type

# Subset to only include categories of 'Dist_taxa' with >=3 studies and >=10 effect sizes (unweighted)
moveDF1 <-as.data.frame(moveDF %>%
 group_by(Movement_type, Disturbance_type, Taxonomic_group) %>%
 filter(n() >9 & n_distinct(Record_number) >2))
moveDF1<-droplevels(moveDF1)

# Subset to only include categories of 'Dist_taxa' with >=3 studies and >=10 effect sizes that have a variance estimate (weighted)
moveDF2 <-as.data.frame(moveDF %>%
 filter(!is.na(Variance))  %>%
 group_by(Movement_type, Disturbance_type, Taxonomic_group) %>%
 filter(n() >9 & n_distinct(Record_number) >2))
moveDF2<-droplevels(moveDF2)

#Unweighted, home range 
dtc1<-brm(lnRR ~ Dist_taxa-1 + (1|Record_number)+(1| Species), data= subset(moveDF1, Movement_type == "Home range" & Disturbance_type != "Other"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)), control = list(adapt_delta = 0.99))
summary(dtc1); plot(dtc1)

#Unweighted, movement distance
dtc2<-brm(lnRR ~ Dist_taxa-1 + (1|Record_number)+(1| Species), data= subset(moveDF1, Movement_type == "Distance" & Disturbance_type != "Other"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)), control = list(adapt_delta = 0.99))
summary(dtc2); plot(dtc2)

#Weighted, home range
dtc3<-brm(lnRR|se(SE, sigma = TRUE) ~ Dist_taxa-1 + (1|Record_number)+(1| Species), data= subset(moveDF2, Movement_type == "Home range" & Disturbance_type != "Other"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)), control = list(adapt_delta = 0.99))
summary(dtc3); plot(dtc3)

#Weighted, movement distance
dtc4<-brm(lnRR|se(SE, sigma = TRUE) ~ Dist_taxa-1 + (1|Record_number)+(1| Species), data= subset(moveDF2, Movement_type == "Distance" & Disturbance_type != "Other"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)), control = list(adapt_delta = 0.99))
summary(dtc4); plot(dtc4)

# Create a model results table
tab_model(dtc2, dtc4, dtc1, dtc3, show.icc = FALSE, show.re.var = FALSE, show.r2 = FALSE, show.ngroups = FALSE, dv.labels=c("MD unweighted", "MD weighted","HR unweighted", "HR weighted"), string.pred = "Disturbance type")

#################################################################################################
## Model set 6: test whether responses vary according to disturbance group (human activity vs. habitat modification)
#Unweighted, home range
dthl1<-brm(lnRR ~ Disturbance_group-1 + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Home range"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(dthl1); plot(dthl1)

#Unweighted, movement rate
dthl2<-brm(lnRR ~ Disturbance_group-1 + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)),control = list(adapt_delta = 0.99))
summary(dthl2); plot(dthl2)
  
 #Weighted, home range
dthl3<-brm(lnRR|se(SE, sigma = TRUE) ~ Disturbance_group-1 + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Home range"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)), control = list(adapt_delta = 0.99))
summary(dthl3); plot(dthl3)

#Weighted, movement distance
dthl4<-brm(lnRR|se(SE, sigma = TRUE) ~ Disturbance_group-1 + (1|Record_number)+(1| Species), data= subset(moveDF, Movement_type == "Distance"), family=gaussian, iter=10000, warmup=1000, cores = 4, chains = 4, seed = 14, prior = c(prior(cauchy(0, 1), sd)), control = list(adapt_delta = 0.99))
summary(dthl4); plot(dthl4)

# Create a model results table
tab_model(dthl2,  dthl4, dthl1, dthl3, show.icc = FALSE, show.re.var = FALSE, show.r2 = FALSE, show.ngroups = FALSE, dv.labels=c("MD unweighted", "MD weighted","HR unweighted", "HR weighted"), string.pred = "Disturbance type")
